==> silk-0.11.2.tar.gz: silk-0.11.2/src/libsktransfer/skt-protocol.h <==
/*
** Copyright (C) 2004-2006 by Carnegie Mellon University.
**
** @OPENSOURCE_HEADER_START@
** 
** Use of the SILK system and related source code is subject to the terms 
** of the following licenses:
** 
** GNU Public License (GPL) Rights pursuant to Version 2, June 1991
** Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
** 
** NO WARRANTY
** 
** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER 
** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY 
** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN 
** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY 
** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT 
** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE, 
** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE 
** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT, 
** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY 
** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF 
** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES. 
** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF 
** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON 
** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE 
** DELIVERABLES UNDER THIS LICENSE.
** 
** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie 
** Mellon University, its trustees, officers, employees, and agents from 
** all claims or demands made against them (and any related losses, 
** expenses, or attorney's fees) arising out of, or relating to Licensee's 
** and/or its sub licensees' negligent use or willful misuse of or 
** negligent conduct or willful misconduct regarding the Software, 
** facilities, or other rights or assistance granted by Carnegie Mellon 
** University under this License, including, but not limited to, any 
** claims of product liability, personal injury, death, damage to 
** property, or violation of any laws or regulations.
** 
** Carnegie Mellon University Software Engineering Institute authored 
** documents are sponsored by the U.S. Department of Defense under 
** Contract F19628-00-C-0003. Carnegie Mellon University retains 
** copyrights in all material produced under this contract. The U.S. 
** Government retains a non-exclusive, royalty-free license to publish or 
** reproduce these documents, or allow others to do so, for U.S. 
** Government purposes only pursuant to the copyright license under the 
** contract clause at 252.227.7013.
** 
** @OPENSOURCE_HEADER_END@
*/
#ifndef _SKT_PROTOCOL_H
#define _SKT_PROTOCOL_H

#include "silk.h"

RCSIDENTVAR(rcsID_SKT_PROTOCOL_H, "$SiLK: skt-protocol.h 2920 2006-02-06 18:02:36Z mthomas $");


/*
**  skt-protocol.h
**
**  Protocol typedefs and defines
**
*/


#define SK_TRANSFER_ACKTIMEOUT 10 /* Number of seconds to wait for ack */

#define SK_TRANSFER_ACK 0
#define SK_TRANSFER_NAK 1

#define SK_TRANSFER_HANDSHAKE 1
#define SK_TRANSFER_FILETRANSFER 2
#define SK_TRANSFER_SHUTDOWN 3

#define SK_TRANSFER_NONE 0
#define SK_TRANSFER_CRC 1
#define SK_TRANSFER_MD5 2
#define SK_TRANSFER_SHA 3

#define SK_TRANSFER_PROTOCOL_V1 1

typedef struct _sk_transfer_file_info_t
{
    uint32_t size;
    char name[56];
} sk_transfer_file_info_t;


typedef struct _sk_transfer_header_prologue_t
{
    uint8_t version;
    uint8_t cksum_type;
    uint8_t type;
    uint8_t reserved[1];
} sk_transfer_header_prologue_t;

#endif /* _SKT_PROTOCOL_H */

==> silk-1.1.3.tar.gz: silk-1.1.3/src/libsktransfer/skt-protocol.h <==
/*
** Copyright (C) 2004-2008 by Carnegie Mellon University.
**
** @OPENSOURCE_HEADER_START@
**
** Use of the SILK system and related source code is subject to the terms
** of the following licenses:
**
** GNU Public License (GPL) Rights pursuant to Version 2, June 1991
** Government Purpose License Rights (GPLR) pursuant to DFARS 252.225-7013
**
** NO WARRANTY
**
** ANY INFORMATION, MATERIALS, SERVICES, INTELLECTUAL PROPERTY OR OTHER
** PROPERTY OR RIGHTS GRANTED OR PROVIDED BY CARNEGIE MELLON UNIVERSITY
** PURSUANT TO THIS LICENSE (HEREINAFTER THE "DELIVERABLES") ARE ON AN
** "AS-IS" BASIS. CARNEGIE MELLON UNIVERSITY MAKES NO WARRANTIES OF ANY
** KIND, EITHER EXPRESS OR IMPLIED AS TO ANY MATTER INCLUDING, BUT NOT
** LIMITED TO, WARRANTY OF FITNESS FOR A PARTICULAR PURPOSE,
** MERCHANTABILITY, INFORMATIONAL CONTENT, NONINFRINGEMENT, OR ERROR-FREE
** OPERATION. CARNEGIE MELLON UNIVERSITY SHALL NOT BE LIABLE FOR INDIRECT,
** SPECIAL OR CONSEQUENTIAL DAMAGES, SUCH AS LOSS OF PROFITS OR INABILITY
** TO USE SAID INTELLECTUAL PROPERTY, UNDER THIS LICENSE, REGARDLESS OF
** WHETHER SUCH PARTY WAS AWARE OF THE POSSIBILITY OF SUCH DAMAGES.
** LICENSEE AGREES THAT IT WILL NOT MAKE ANY WARRANTY ON BEHALF OF
** CARNEGIE MELLON UNIVERSITY, EXPRESS OR IMPLIED, TO ANY PERSON
** CONCERNING THE APPLICATION OF OR THE RESULTS TO BE OBTAINED WITH THE
** DELIVERABLES UNDER THIS LICENSE.
**
** Licensee hereby agrees to defend, indemnify, and hold harmless Carnegie
** Mellon University, its trustees, officers, employees, and agents from
** all claims or demands made against them (and any related losses,
** expenses, or attorney's fees) arising out of, or relating to Licensee's
** and/or its sub licensees' negligent use or willful misuse of or
** negligent conduct or willful misconduct regarding the Software,
** facilities, or other rights or assistance granted by Carnegie Mellon
** University under this License, including, but not limited to, any
** claims of product liability, personal injury, death, damage to
** property, or violation of any laws or regulations.
**
** Carnegie Mellon University Software Engineering Institute authored
** documents are sponsored by the U.S. Department of Defense under
** Contract F19628-00-C-0003. Carnegie Mellon University retains
** copyrights in all material produced under this contract. The U.S.
** Government retains a non-exclusive, royalty-free license to publish or
** reproduce these documents, or allow others to do so, for U.S.
** Government purposes only pursuant to the copyright license under the
** contract clause at 252.227.7013.
**
** @OPENSOURCE_HEADER_END@
*/
#ifndef _SKT_PROTOCOL_H
#define _SKT_PROTOCOL_H

#include "silk.h"

RCSIDENTVAR(rcsID_SKT_PROTOCOL_H, "$SiLK: skt-protocol.h 10004 2008-01-04 23:08:59Z mthomas $");


/*
**  skt-protocol.h
**
**  Protocol typedefs and defines
**
*/


#define SK_TRANSFER_ACKTIMEOUT 10 /* Number of seconds to wait for ack */

#define SK_TRANSFER_ACK 0
#define SK_TRANSFER_NAK 1

#define SK_TRANSFER_HANDSHAKE 1
#define SK_TRANSFER_FILETRANSFER 2
#define SK_TRANSFER_SHUTDOWN 3

#define SK_TRANSFER_NONE 0
#define SK_TRANSFER_CRC 1
#define SK_TRANSFER_MD5 2
#define SK_TRANSFER_SHA 3

#define SK_TRANSFER_PROTOCOL_V1 1

typedef struct sk_transfer_file_info_st {
    uint32_t size;
    char name[56];
} sk_transfer_file_info_t;


typedef struct sk_transfer_header_prologue_st {
    uint8_t version;
    uint8_t cksum_type;
    uint8_t type;
    uint8_t reserved[1];
} sk_transfer_header_prologue_t;

#endif /* _SKT_PROTOCOL_H */

/*
** Local Variables:
** mode:c
** indent-tabs-mode:nil
** c-basic-offset:4
** End:
*/
